pub struct Input {
pub resource: Option<Resource>,
pub mode: Option<FHIRCode>,
pub profile: Option<FHIRUri>,
}Fields
resource: Option<Resource>Must be present unless the mode is “delete”
mode: Option<FHIRCode>Default is ‘no action’; (e.g. general validation)
profile: Option<FHIRUri>If this is nominated, then the resource is validated against this specific profile. If a profile is nominated, and the server cannot validate against the nominated profile, it SHALL return an error